==> schluessel-0.1.0-src.zip: schluessel/src/net/morilib/lisp/InitLispLoader.java <==
/*
 * Copyright 2009 Yuichiro Moriguchi
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.morilib.lisp;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.util.Properties;

import net.morilib.lisp.util.LispHandler;
import net.morilib.util.Utils;

public final class InitLispLoader {
	
	private static final String INIT_XML =
		"/net/morilib/lisp/init/initlisp.xml";
	
	private static Properties initProp = null;
	
	public static void load(Scheme lsp) {
		if(initProp == null) {
			synchronized(InitLispLoader.class) {
				InputStream ins = null;
				
				// ꥹȤ򸡺
				try {
					initProp = new Properties();
					ins = InitLispLoader.class.getResourceAsStream(INIT_XML);
					initProp.loadFromXML(ins);
				} catch (IOException e) {
					throw new RuntimeException(
							"Cannot load propfile", e);
				} finally {
					Utils.close(ins);
				}
			}
		}
		
		// Ķ(subroutine, syntax)ۤ
		for(Object s : initProp.values()) {
			load1(lsp, (String)s);
		}
	}
	
	
	public static void loadNullEnv(Scheme lsp, int ver) {
		// do nothing
	}
	
	
	public static void loadRnRSEnv(Scheme lsp, int ver) {
		switch(ver) {
		case 5:
			load1(lsp, "/net/morilib/lisp/init/r5rs.scm");
			break;
		}
	}
	
	
	private static void load1(Scheme lsp, String fn) {
		InputStream ins = null;
		
		try {
			Reader rd;
			
			LispHandler.setLoggable2(false);
			ins = InitLispLoader.class.getResourceAsStream(fn);
			rd = new InputStreamReader(ins);
			lsp.readFile(rd);
			LispHandler.setLoggable2(true);
		} catch (IOException e) {
			throw new RuntimeException(
					"Cannot load initfile", e);
		} finally {
			Utils.close(ins);
		}
	}
	
}

==> schluessel-0.1.2-src.zip: schluessel/src/net/morilib/lisp/InitLispLoader.java <==
/*
 * Copyright 2009 Yuichiro Moriguchi
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.morilib.lisp;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.util.Properties;

import net.morilib.lisp.util.LispHandler;
import net.morilib.util.IOs;

public final class InitLispLoader {
	
	private static final String INIT_XML =
		"/net/morilib/lisp/init/initlisp.xml";
	
	private static Properties initProp = null;
	
	public static void load(Scheme lsp) {
		if(initProp == null) {
			synchronized(InitLispLoader.class) {
				InputStream ins = null;
				
				// 初期化一覧リストを検索する
				try {
					initProp = new Properties();
					ins = InitLispLoader.class.getResourceAsStream(INIT_XML);
					initProp.loadFromXML(ins);
				} catch (IOException e) {
					throw new RuntimeException(
							"Cannot load propfile", e);
				} finally {
					IOs.close(ins);
				}
			}
		}
		
		// 初期環境(subroutine, syntax)を構築する
		for(Object s : initProp.values()) {
			load1(lsp, (String)s);
		}
	}
	
	
	public static void loadNullEnv(Scheme lsp, int ver) {
		// do nothing
	}
	
	
	public static void loadRnRSEnv(Scheme lsp, int ver) {
		switch(ver) {
		case 5:
			load1(lsp, "/net/morilib/lisp/init/r5rs.scm");
			break;
		}
	}
	
	
	private static void load1(Scheme lsp, String fn) {
		InputStream ins = null;
		
		try {
			Reader rd;
			
			LispHandler.setLoggable2(false);
			ins = InitLispLoader.class.getResourceAsStream(fn);
			rd = new InputStreamReader(ins);
			lsp.readFile(rd);
			LispHandler.setLoggable2(true);
		} catch (IOException e) {
			throw new RuntimeException(
					"Cannot load initfile", e);
		} finally {
			IOs.close(ins);
		}
	}
	
}
